summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--test/player_test.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/player_test.cc b/test/player_test.cc
index 2be525d88..1736bfc7e 100644
--- a/test/player_test.cc
+++ b/test/player_test.cc
@@ -222,7 +222,7 @@ BOOST_AUTO_TEST_CASE (player_seek_test)
pair<shared_ptr<PlayerVideo>, DCPTime> video = butler->get_video();
BOOST_CHECK_EQUAL(video.second.get(), t.get());
write_image(video.first->image(bind(PlayerVideo::force, _1, AV_PIX_FMT_RGB24), false, true), String::compose("build/test/player_seek_test_%1.png", i), "RGB");
/* This 0.011 is empirically chosen (hopefully) to accept changes in rendering between the reference and a test machine
(17.10 and 16.04 seem to anti-alias a little differently) but to reject gross errors e.g. missing fonts or missing
text altogether.
*/
@@ -255,7 +255,7 @@ BOOST_AUTO_TEST_CASE (player_seek_test2)
pair<shared_ptr<PlayerVideo>, DCPTime> video = butler->get_video();
BOOST_CHECK_EQUAL(video.second.get(), t.get());
write_image(video.first->image(bind(PlayerVideo::force, _1, AV_PIX_FMT_RGB24), false, true), String::compose("build/test/player_seek_test2_%1.png", i), "RGB");
- check_image(String::compose("test/data/player_seek_test2_%1.png", i), String::compose("build/test/player_seek_test2_%1.png", i), 0.011);
+ check_image(String::compose("test/data/player_seek_test2_%1.png", i), String::compose("build/test/player_seek_test2_%1.png", i), 0.055);
}
}
@@ -222,7 +222,7 @@ BOOST_AUTO_TEST_CASE (player_seek_test)
BOOST_CHECK_EQUAL(video.second.get(), t.get());
write_image(video.first->image(bind(PlayerVideo::force, _1, AV_PIX_FMT_RGB24), false, true), String::compose("build/test/player_seek_test_%1.png", i), "RGB");
- /* This 0.011 is empirically chosen (hopefully) to accept changes in rendering between the reference and a test machine
+ /* This 0.055 is empirically chosen (hopefully) to accept changes in rendering between the reference and a test machine
(17.10 and 16.04 seem to anti-alias a little differently) but to reject gross errors e.g. missing fonts or missing
text altogether.